import request from "supertest";
import { server } from "@/server";
import { mockConfig } from "../../test_setup/mockConfig";

describe("server", () => {
    let consoleSpy;
    beforeAll(() => {
        consoleSpy = vi.spyOn(console, "error").mockImplementation(() => {});
    });
    afterAll(() => {
        server.close();
    });
    it("should return 401 if no session is provided", async () => {
        mockConfig.use_session = false;
        // this should also be returned on any request to the server
        await request(server).get("/auth").expect(401);
        mockConfig.use_session = true;

        await request(server).get("/auth").expect(200);
    });

    it("should return 500 if internal error occurs", async () => {
        const res = await request(server)
            .get("/error")
            .expect(500)
            .expect("Content-Type", /json/);
        expect(res.body).toEqual({
            error: "Internal Server Error",
            details: "TestError",
        });
    });
    it("should return 200 if normal request", async () => {
        await request(server).get("/ping").expect(200).expect("pong");
    });
});
