"use client";

import useUser from "lib/hooks/useUser";
import { createContext, ReactNode, useContext } from "react";

import {
    GroupDataWithMembers,
    UserConfigData,
    UserData,
} from "@snip/database/types";

export interface UserProfileContextI {
    user?: UserData;
    config?: UserConfigData;
    isLoading: boolean;
    updateUser: (
        userData?: UserData,
        userConfig?: Partial<UserConfigData> & { id: number },
        userGroups?: Required<GroupDataWithMembers>[],
    ) => Promise<void>;
}

export const useUserProfile = () => {
    const context = useContext(UserProfileContext);
    if (!context) {
        throw new Error(
            "useUserProfile must be used within a UserProfileProvider",
        );
    }
    return context;
};

const UserProfileContext = createContext<UserProfileContextI | null>(null);

export const UserProfileProvider = ({ children }: { children: ReactNode }) => {
    const { user, config, isLoading, updateUser } = useUser(true);

    return (
        <UserProfileContext.Provider
            value={{
                user,
                config,
                isLoading,
                updateUser,
            }}
        >
            {children}
        </UserProfileContext.Provider>
    );
};
