"use client";

import { redirect } from "next/navigation";
import { FormEventHandler, useState } from "react";
import { InputGroup } from "react-bootstrap";
import { useFormState } from "react-dom";

import { checkVerifiedFormAction } from "../action";

import { Form, FormHeader } from "components/form";
import { FormError } from "components/form/alert";
import { SubmitButton } from "components/form/buttons";
import { TextInput } from "components/form/inputs/text";

export function ResendForm({ email }: { email: string }) {
    const [pending, setPending] = useState(false);
    const [emailSend, setEmailSend] = useState(false);
    const [error, setError] = useState(null);

    const onSubmit: FormEventHandler<HTMLFormElement> = async (e) => {
        e.preventDefault();
        setPending(true);
        const res = await fetch("/email/account/verifyEmail", {
            method: "POST",
        });
        const body = await res.json();
        if (!res.ok) {
            setError(body.details || body.error);
            setPending(false);
            return;
        }
        setEmailSend(true);

        setTimeout(() => {
            setPending(false);
        }, 2000);
    };

    return (
        <Form data-glassmorphism="false" onSubmit={onSubmit}>
            <p className="mt-3 text-center">You did not receive an email?</p>
            <FormError>{error}</FormError>
            <SubmitButton
                className="btn btn-outline-secondary"
                style={{ width: "350px", height: "4rem" }}
                pending={pending}
                disabled={emailSend}
            >
                {emailSend ? (
                    <span>We send you an email to</span>
                ) : (
                    <span>Resend verification email to</span>
                )}
                <br></br>
                <code>{email}</code>
            </SubmitButton>
        </Form>
    );
}

export function VerifyForm() {
    // @ts-expect-error form
    const [state, formAction] = useFormState(checkVerifiedFormAction, {
        error: null,
        user: null,
    });

    if (state.user?.emailValidated) {
        redirect("/frontpage");
    }

    return (
        <Form action={formAction}>
            <FormHeader>Verify your email!</FormHeader>
            <FormError>{state.error}</FormError>
            <p>
                We have sent you an email with a verification link. Please click
                on the link to verify your email. Alternatively, you can enter
                the verification code we send in that email below.
            </p>
            <InputGroup className="mt-3 mb-3 w-100">
                <TextInput
                    name="token"
                    label="Verification code"
                    style={{ flexGrow: "1" }}
                />
                <SubmitButton
                    style={{ flexShrink: "0" }}
                    className="btn btn-primary"
                >
                    Verify
                </SubmitButton>
            </InputGroup>
        </Form>
    );
}
