import { GET, POST } from "../groups/route";
import { NotFoundError } from "@snip/database/errors";
import {
    GroupData,
    GroupDataWithMembers,
    GroupMemberData,
} from "@snip/database/types";
import { resetMockConfig, setSessionType } from "__mocks__/mockConfig";
import { createMockRequest } from "__mocks__/request";

jest.mock("@snip/database", () => {
    return {
        group: {
            getByUserId: jest.fn(async (id): Promise<GroupData[]> => {
                return [
                    {
                        id: 1,
                        name: "Group 1",
                        description: "This is a group",
                    },
                ];
            }),
            getMembers: jest.fn(async (id): Promise<GroupMemberData[]> => {
                return [
                    {
                        user_id: 1,
                        group_id: id,
                        role: "member" as const,
                        email: "test@test.de",
                    },
                ];
            }),
            insert: jest.fn(async (a) => {
                return a;
            }),
            addMember: jest.fn(async () => {
                return {
                    user_id: 1,
                    group_id: 1,
                    role: "owner",
                };
            }),
        },
    };
});

describe("GET api/account/groups", () => {
    beforeEach(() => {
        resetMockConfig();
    });

    it("should return 401 if user is not logged in", async () => {
        setSessionType("none");
        const req = await createMockRequest({
            method: "GET",
        });
        const res = await GET(req, {});
        expect(res.status).toBe(401);
    });

    it("should return 200", async () => {
        const req = await createMockRequest({
            method: "GET",
        });
        const res = await GET(req, {});
        console.error(await res.json());
        expect(res.status).toBe(200);
    });
});

describe("POST api/account/groups", () => {
    beforeEach(() => {
        resetMockConfig();
    });

    it("should return 401 if user is not logged in", async () => {
        setSessionType("none");
        const req = await createMockRequest({
            method: "POST",
            content_type: "application/json",
            body: { name: "Test" },
        });
        const res = await POST(req, {});
        expect(res.status).toBe(401);
    });

    it("should create a group", async () => {
        const req = await createMockRequest({
            method: "POST",
            content_type: "application/json",
            body: { name: "Test" },
        });
        const res = await POST(req, {});
        expect(res.status).toBe(200);
        expect(await res.json()).toEqual({
            name: "Test",
            members: [
                {
                    user_id: 1,
                    group_id: 1,
                    self: true,
                    role: "owner",
                },
            ],
        });
    });
});

describe("GET api/account/groups/[id]", () => {
    test.todo("tests add member");
    test.todo("tests remove member");
    test.todo("tests get members");
});
