import sharp from "sharp";
import { Canvas, Image, Path2D } from "skia-canvas";

import { BaseSnip } from "@snip/snips/general/base";
import { ImageSnip } from "@snip/snips/general/image";
import { ImageSnipLegacy } from "@snip/snips/general/legacy/image";

BaseSnip.prototype.createCanvas = function (width: number, height: number) {
    return new Canvas(width, height) as unknown as OffscreenCanvas;
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const get_bitmap = async function (this: any) {
    this.bitmap = new Image();
    const promise = new Promise((resolve, reject) => {
        this.bitmap.onload = () => {
            resolve(true);
        };
        this.bitmap.onerror = (error: unknown) => {
            reject(error);
        };
    });

    if (this.blob.mime === "image/webp") {
        const png_buffer = await sharp(Buffer.from(this.blob.data, "base64"))
            .toFormat("png")
            .toBuffer();
        this.bitmap.src = `data:image/png;base64,${png_buffer.toString("base64")}`;
    } else {
        this.bitmap.src = `data:${this.blob.mime};base64,${this.blob.data}`;
    }
    await promise;

    this.img_width = this.bitmap.width;
    this.img_height = this.bitmap.height;
    // Overwrite default values if not set
    this._swidth = this.swidth || this.img_width;
    this._sheight = this.sheight || this.img_height;
    this._width = this.width || this.img_width;
    this._height = this.height || this.img_height;
    return true;
};

ImageSnipLegacy.prototype.get_bitmap = get_bitmap;
ImageSnip.prototype.get_bitmap = get_bitmap;

globalThis.Path2D = Path2D;
