// Mock the loadJsonFile method for testing
vi.doMock("@snip/database", async (importOriginal) => {
    const { NotFoundError } = await vi.importActual<
        typeof import("@snip/database/errors")
    >("@snip/database/errors");
    const { readFileSync } = await vi.importActual<typeof import("fs")>("fs");
    const { mockConfig } = await import("./mockConfig");

    return {
        default: {
            page: {
                getById: async (id: string) => {
                    if (parseInt(id) == 9999) {
                        throw new NotFoundError("Page", 9999);
                    }
                    const data = readFileSync(
                        import.meta.dirname + "/data/pageData.json",
                        "utf8",
                    );
                    return JSON.parse(data);
                },
                getFirstByBookId: vi.fn().mockResolvedValue({ id: 123 }),
                getCoverByBookId: async (id: number) => {
                    const data = readFileSync(
                        import.meta.dirname + "/data/pageData.json",
                        "utf8",
                    );
                    return JSON.parse(data);
                },
            },
            snip: {
                getByPageId: async () => {
                    const data = readFileSync(
                        import.meta.dirname + "/data/snips.json",
                        "utf8",
                    );
                    return JSON.parse(data);
                },
            },
            permission: {
                getByUserAndPageIdReduced: async (
                    user_id: number,
                    page_id: number,
                ) => {
                    return {
                        pRead: mockConfig.pRead,
                    };
                },
                getByUserAndBookReduced: async (
                    user_id: number,
                    book_id: number,
                ) => {
                    return {
                        pRead: mockConfig.pRead,
                    };
                },
            },
            group: {
                getByUserId: async (user_id: number) => {
                    // Only needed to test admin auth
                    if (mockConfig.is_admin) {
                        return [
                            {
                                id: 1,
                            },
                        ];
                    } else {
                        return [];
                    }
                },
            },
        },
    };
});

vi.doMock("@snip/database/sql.connection", () => {
    return {
        pool_data: {
            end: vi.fn(),
        },
        pool_permissions: {
            end: vi.fn(),
        },
    };
});

vi.doMock("fast-glob", () => {
    return {
        default: {
            glob: async (query: string) => {
                // Test 2 sizes
                if (query.includes(".pdf")) {
                    return ["1400.pdf"];
                }
                if (query.includes(".jpeg")) {
                    return ["200.jpeg"];
                }
                if (query.includes(".webp")) {
                    return ["200.webp"];
                }
                return [];
            },
        },
    };
});

vi.doMock("fs", async (importOriginal) => {
    const cloneFs = await importOriginal<typeof import("fs")>();
    return {
        ...cloneFs,

        createReadStream: (path: string) => {
            if (path.includes(".pdf")) {
                return cloneFs.createReadStream(
                    import.meta.dirname + "/data/test.pdf",
                );
            }
            if (path.includes(".jpeg")) {
                return cloneFs.createReadStream(
                    import.meta.dirname + "/data/test.jpeg",
                );
            }
        },
    };
});

vi.mock("@snip/config/server", async (importOriginal) => {
    const actualModule =
        await importOriginal<typeof import("@snip/config/server")>();
    return {
        config: {
            RENDER: {
                ...actualModule.config.RENDER,
                DIR: import.meta.dirname + "/data/tmp",
            },
        },
    };
});

// Moock session
vi.mock("@snip/auth/session", async (importOriginal) => {
    const { mockConfig } = await import("./mockConfig");
    const actualModule =
        await importOriginal<typeof import("@snip/auth/session")>();
    return {
        ...actualModule,
        getSession: async () => {
            const ret = {
                user: {
                    id: 1,
                },
            } as any;
            if (mockConfig.force_api_session) {
                return {
                    api: "test",
                };
            }
            if (mockConfig.session) {
                return ret;
            } else {
                return {};
            }
        },
    };
});

// Mock fetch
global.fetch = vi.fn(
    () =>
        Promise.resolve({
            text: () => {
                //wait 2 seconds
                return new Promise((resolve) => {
                    setTimeout(() => {
                        resolve("test");
                    }, 2000);
                });
            },
        }),
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
) as any;
